# Table of Contents

- [modeling-sap-btp](<./modeling-sap-btp.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Modeling SAP BTP](<./Modeling-SAP-BTP.md>)
  - [Introduction](<./Modeling-SAP-BTP/Introduction.md>)
  - [Gaining Insights from SAP BTP Modeling](<./Modeling-SAP-BTP/Gaining-Insights-from-SAP-BTP-Modeling.md>)
  - [Documenting SAP BTP Usage in the Application Landscape](<./Modeling-SAP-BTP/Documenting-SAP-BTP-Usage-in-the-Application-Landscape.md>)
  - [Visualizing Tech Standards Usage and Governance Compliance](<./Modeling-SAP-BTP/Visualizing-Tech-Standards-Usage-and-Governance-Compliance.md>)
  - [Building up SAP BTP as a Strategic Platform](<./Modeling-SAP-BTP/Building-up-SAP-BTP-as-a-Strategic-Platform.md>)
  - [Support Agile Development](<./Modeling-SAP-BTP/Support-Agile-Development.md>)
  - [General Guidelines and Best Practices for SAP BTP Modeling](<./Modeling-SAP-BTP/General-Guidelines-and-Best-Practices-for-SAP-BTP-Modeling.md>)
  - [Was this page helpful?](<./Modeling-SAP-BTP/Was-this-page-helpful.md>)
  - [We'd love your feedback!](<./Modeling-SAP-BTP/Wed-love-your-feedback.md>)
